@@ -12,6 +12,21 @@ logger = setup_logger(__name__)
 
 command_registry = []
 
+
+def cmd(commands):
+    # Normalize: accept str or list
+    prefixes = "/"
+    if isinstance(commands, str):
+        commands = [commands]
+    async def func(flt, client, message):
+        text = message.text or message.caption or ""
+        for cmd in commands:
+            if text.startswith(f"{prefixes}{cmd}"):
+                return True
+        return False
+    return filters.create(func)
+
+
 def get_priority(description: str) -> int:
     desc_lower = description.lower()
     if "(owner only)" in desc_lower:
@@ -30,7 +45,7 @@ def reorder_command_registry():
 def get_commands():
     return command_registry
 
-def command(command: Union[str, list], description: str):
+def command(command: Union[str, list], description: str,Custom_filter=None):
     def decorator(func):
         command_registry.append({
             "command": command,
@@ -38,7 +53,11 @@ def command(command: Union[str, list], description: str):
             "handler": func
         })
         logger.info(f"Registered command: {command} - {description}")
-        @Client.on_message(filters.command(command))
+        if Custom_filter:
+            filter = cmd(command, prefixes=["/"]) & Custom_filter
+        else:
+            filter = cmd(command, prefixes=["/"])
+        @Client.on_message(filter)
         @wraps(func)
         async def wrapper(client, message):
             return await func(client, message)
