@@ -4,7 +4,7 @@ import re
 
 from typing import List, Optional, Union
 
-from pyrogram import Client
+from pyrogram import Client , filters
 from pyrogram.enums import ParseMode
 from pyrogram.types import Message, CallbackQuery
 
@@ -50,11 +50,9 @@ class FontMessageMixin(Client):
             return await message.answer(text, show_alert=True)
 
 
-    async def get_messages(self, chat_id: Union[int, str], reply_to_message_ids: List[int], replies: int, end: int, start: int = 0, message_ids: List[int] = []) -> List[Message]:
+    async def index_message(self, chat_id: Union[int, str], end: int, start: int = 0) -> List[Message]:
         messages_list = []
         current = start
-        if message_ids != []:
-            return await super().get_messages(chat_id=chat_id, message_ids=message_ids, reply_to_message_ids=reply_to_message_ids, replies=replies)
         while True:
             new_diff = min(200, end - current)
             if new_diff <= 0:break
@@ -63,6 +61,15 @@ class FontMessageMixin(Client):
             current += len(messages)
         return messages_list
 
+def web_app_data_filter(self,key_value):
+    async def filter_func(flt, client, update: Message):
+        if update.web_app_data:
+            return update.web_app_data.data.startswith(key_value)
+        return False
+    return filters.create(filter_func)
+
+web_app_data = filters.create(web_app_data_filter)
+
 def get_font(text: str, font: int = 1):
     if int(font) ==0:return text
     font_name = f"__font{font}"
